'''
 NAME:                datacubes_1_python

 DESCRIPTION:         Displays a contour plot on a datacube slice

 EXECUTION COMMAND:
                      > python datacubes_1_python.py
                      

 INPUTS:              FITS datacube ngg4151_hband.fits
                    
 OUTPUTS:             PDF file: python_plot.pdf

 NOTES:               change the input data. 
                      change the output PDF name.


 AUTHORS:              Derek HAMMER, Tommy LE BLANC
                      Space Telescope Science Institute, USA 
 
 REVISION HISTORY:
                      Written by Derek HAMMER, Tommy LE BLANC, NOV 2012. 

'''


# ------------------------ python code begins here

        
#! /usr/bin/env python

# Header


# Import necessary modules
import pyfits as pf
import matplotlib.pyplot as plt

# read datacube
f = pf.open('ngc4151_hband.fits')
cube = f[1].data
header = f[1].header
f.close()

# we plot slice 1067
cube_slice = 1067
image = cube[cube_slice, :, :]
tam = image.shape

# display the background image
fig, ax = plt.subplots()
alplot = ax.imshow(image, vmin = 0, vmax = 100)
alplot.set_cmap('hot')

# define axes
ax.set_xlabel('x pixels')
ax.set_ylabel('y pixels')
ax.set_ylim([0, tam[0]-1])
ax.set_xlim([0, tam[1]-1])

# create contours
levels = [5, 10, 20, 30, 40, 50, 100, 200, 600]
ax.contour(image, levels, colors='g')

fig.savefig('python_plot.pdf')

# ------------------------ python code ends here

        
